#   This file is part of Software Center Ratings and Reviews
#   Copyright (C) 2010 Canonical Ltd.
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Decorators used in the Ratings and Reviews API."""

from __future__ import absolute_import

__metaclass__ = type
__all__ = [
    'dont_vary',
    ]

from functools import wraps

from django.conf import settings
from django.views.decorators.gzip import gzip_page

def dont_vary(func):
    """A decorator that removes any Vary header the response has."""
    @wraps(func)
    def wrapper(*args, **kwargs):
        response = func(*args, **kwargs)
        if 'vary' in response:
            del response['vary']
        return response
    return wrapper

def gzip_content(func):
    """A decorator that gzip-encodes content, based on a setting."""
    @wraps(func)
    def wrapper(*args, **kwargs):
        if getattr(settings, 'ENABLE_GZIP_CONTENT', True):
            response = gzip_page(func)(*args, **kwargs)
        else:
            response = func(*args, **kwargs)
        return response
    return wrapper
        