from django.conf import settings
from django.db import models

# custom db type field to accomodate postgresql's debversion field
# if not postgresql, just acts like a normal CharField
class DebVersionField(models.CharField):
    def __init__(self, *args, **kwargs):
        super(DebVersionField, self).__init__(*args, **kwargs)

    def db_type(self, connection=None):
        # Django 1.1 db_type does not take a connection arg (as
        # it doesn't support multiple database.)
        try:
            engine = settings.DATABASES['default']['ENGINE']
        except AttributeError:
            engine = settings.DATABASE_ENGINE

        if 'postgresql_psycopg2' in engine:
            return 'debversion'
        else:
            kwargs = {}
            if connection:
                kwargs['connection'] = connection
            return super(DebVersionField, self).db_type(**kwargs)

from south.modelsinspector import add_introspection_rules
add_introspection_rules([], ["^reviewsapp\.fields\.DebVersionField"])
