import django

# This conditional import is to support reorganization of the code in latest
# configglue branch (the one required by django-configglue trunk).
try:
    from configglue.pyschema import ConfigSection
    from configglue.pyschema.options import (
        BoolConfigOption, DictConfigOption,
        IntConfigOption, LinesConfigOption, StringConfigOption
    )
except ImportError:
    from configglue.pyschema.schema import (
        ConfigSection, BoolConfigOption, DictConfigOption, IntConfigOption,
        LinesConfigOption, StringConfigOption
    )

from django_configglue.schema import schemas, Django112Schema

# Currently we've updated to latest configglue/django-configglue
# but they remove a registered schema for django 1.1.1, which is
# the currently installed django version on our servers, resulting in:
# http://razorgirl.info/job/software-center-agent-deploy/23/console
# So we register the 112 schema to match until we upgrade. Once we
# upgraded this should still work without updating (as the version
# will be 1.3).
schemas.register(Django112Schema, '1.1.1')

DjangoSchema = schemas.get(django.get_version())


class RnRSchema(DjangoSchema):
    # default
    pgconnect_timeout = IntConfigOption(default=10)
    serve_static_media = BoolConfigOption()
    extra_pythonpath = LinesConfigOption(item=StringConfigOption())
    default_timeout = IntConfigOption(default=None)

    # openid
    openid = ConfigSection()
    openid.openid_create_users = BoolConfigOption()
    openid.openid_reuse_users = BoolConfigOption()
    openid.openid_launchpad_teams_mapping = DictConfigOption()
    openid.openid_sso_server_url = StringConfigOption()
    openid.openid_set_language_from_sreg = BoolConfigOption()
    openid.openid_update_details_from_sreg = BoolConfigOption()
    openid.openid_sreg_extra_fields = LinesConfigOption(
        item=StringConfigOption())
    openid.openid_sreg_required_fields = LinesConfigOption(
        item=StringConfigOption())
    openid.openid_launchpad_staff_teams = LinesConfigOption(
        item=StringConfigOption())

    # logging
    logging = ConfigSection()
    logging.oops_dir = StringConfigOption(help='Absolute path to the'
        'directory oops reports will be stored in')
    logging.logging_config_file = StringConfigOption(fatal=True)

    # loadtest
    loadtest = ConfigSection()
    loadtest.enable_statistics_logging = BoolConfigOption()
    loadtest.network_interfaces = LinesConfigOption(item=StringConfigOption())
    loadtest.disks = LinesConfigOption(item=StringConfigOption())
    loadtest.seconds_between_logging = IntConfigOption(default=5)
    loadtest.stats_to_log = LinesConfigOption(item=StringConfigOption())

    # SSO API
    sso_api = ConfigSection()
    sso_api.sso_api_service_root = StringConfigOption()
    sso_api.sso_api_auth_username = StringConfigOption()
    sso_api.sso_api_auth_password = StringConfigOption()
    sso_api.sso_api_identity_prefix = StringConfigOption()
    sso_api.sso_auth_mode_no_ubuntu_sso_plaintext_only = BoolConfigOption()

    # RnR
    rnr = ConfigSection()
    rnr.moderators_group = StringConfigOption()
    rnr.preload_api_service_roots = BoolConfigOption()
    rnr.api_reviews_pagination = IntConfigOption()
    rnr.cache_review_stats_seconds = IntConfigOption()
    rnr.token_cache_expiry_hours = IntConfigOption(default=4)
    rnr.reviewsapp_media_root = StringConfigOption()
    rnr.force_https_in_environment = BoolConfigOption()
    rnr.allow_multiple_reviews_for_testing = BoolConfigOption(default=False)
    rnr.enable_artificial_oops = BoolConfigOption()
    rnr.modify_window_minutes = IntConfigOption()
    rnr.enable_gzip_content = BoolConfigOption(default=True)
    rnr.enable_histogram_data = BoolConfigOption(default=True)

    # Launchpad
    launchpad = ConfigSection()
    launchpad.lp_service = StringConfigOption()
    launchpad.lp_consumer_name = StringConfigOption()
    launchpad.launchpadlib_dir = StringConfigOption(
        default='/tmp/.launchpadlib')

    # Piston
    piston = ConfigSection()
    piston.oauth_data_store = StringConfigOption()

    # Softwarecenter agent.
    sca = ConfigSection()
    sca.sca_host_url = StringConfigOption(
        default='https://software-center.ubuntu.com/')
    sca.sca_apps_cache_timeout = IntConfigOption(default=3600)

    # preflight
    preflight = ConfigSection()
    preflight.preflight_base_template = StringConfigOption(
        default="light/index.1col.html")
    preflight.preflight_table_class = StringConfigOption(default="listing")
