#   -*- coding: utf-8 -*-
#   This file is part of Software Center Ratings and Reviews
#   Copyright (C) 2010-2011 Canonical Ltd.
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Tests for the 'populate' command."""

__metaclass__ = type
__all__ = [
    'PopulateCommandTestCase',
    ]

from django.conf import settings
from django.core.management import call_command
from django.contrib.auth.models import User
from django.contrib.sessions.models import Session
from django.test import TestCase

from reviewsapp.models import (
    Review,
    SoftwareItem,
)
from reviewsapp.utilities import is_using_postgres

class PopulateCommandTestCase(TestCase):
    def tearDown(self):
        for model in [Session, User, Review, SoftwareItem]:
            model.objects.all().delete()

    setUp = tearDown

    def check_populate_populates_correctly(self, nsoftwareitems=0, nreviews=0,
        nsessions=0, nusers=0):
        self.assertEqual(0, User.objects.count())
        self.assertEqual(0, Session.objects.count())
        self.assertEqual(0, Review.objects.count())
        self.assertEqual(0, SoftwareItem.objects.count())

        call_command('populate', softwareitems=nsoftwareitems,
            reviews=nreviews, sessions=nsessions,
            users=nusers, verbosity=0)

        self.assertEqual(nusers, User.objects.count())
        self.assertEqual(nsessions, Session.objects.count())
        self.assertEqual(nreviews, Review.objects.count())
        self.assertEqual(nsoftwareitems, SoftwareItem.objects.count())

    def test_populate_users(self):
        self.check_populate_populates_correctly(nusers=15)

    def test_populate_sessions(self):
        self.check_populate_populates_correctly(nsessions=15)

    def test_populate_softwareitems(self):
        # XXX 2011-09-08 michael.nelson Skipping for sqlite
        # bug=http://south.aeracode.org/ticket/919
        # SQLite columns get re-ordered by the south (>= 0.7) and since
        # the populate command is only used for performance testing
        # (ie. with postgres) we skip this test for sqlite (switch to
        # skipUnless when we've got 1.3 on CI).
        if is_using_postgres():
            self.check_populate_populates_correctly(nsoftwareitems=15)

    def test_populate_reviews(self):
        # XXX 2011-09-08 michael.nelson Skipping for sqlite
        # bug=http://south.aeracode.org/ticket/919
        # SQLite columns get re-ordered by the south (>= 0.7) and since
        # the populate command is only used for performance testing
        # (ie. with postgres) we skip this test for sqlite (switch to
        # skipUnless when we've got 1.3 on CI).
        if is_using_postgres():
            self.check_populate_populates_correctly(nreviews=15,
                nusers=1, nsoftwareitems=1)

